@@ -375,6 +375,8 @@ impl PlutusData {
 #[derive(Clone, Debug, Eq, Ord, PartialEq, PartialOrd)]
 pub struct PlutusList(Vec<PlutusData>);
 
+to_from_bytes!(PlutusList);
+
 #[wasm_bindgen]
 impl PlutusList {
     pub fn new() -> Self {
@@ -475,6 +477,8 @@ impl RedeemerTag {
 #[derive(Clone, Debug, Eq, Ord, PartialEq, PartialOrd)]
 pub struct Redeemers(Vec<Redeemer>);
 
+to_from_bytes!(Redeemers);
+
 #[wasm_bindgen]
 impl Redeemers {
     pub fn new() -> Self {
@@ -628,7 +632,7 @@ impl Deserialize for ConstrPlutusData {
 
 impl cbor_event::se::Serialize for CostModel {
     fn serialize<'se, W: Write>(&self, serializer: &'se mut Serializer<W>) -> cbor_event::Result<&'se mut Serializer<W>> {
-        serializer.write_map(cbor_event::Len::Len(COST_MODEL_OP_COUNT as u64))?;
+        serializer.write_array(cbor_event::Len::Len(COST_MODEL_OP_COUNT as u64))?;
         for cost in &self.0 {
             cost.serialize(serializer)?;
         }
